@@ -99,7 +99,7 @@ my @NAME_SECTION_MAPPINGS = (
     [qr/-dbg(?:sym)?$/                => 'debug'],
     [qr/^(?:python-)?zope/            => 'zope'],
     [qr/^python-/                     => 'python'],
-    [qr/^r-cran-/                     => 'gnu-r'],
+    [qr/^r-(?:cran|bioc|other)-/      => 'gnu-r'],
     [qr/^lib.*-perl$/                 => 'perl'],
     [qr/^lib.*-cil(?:-dev)?$/         => 'cli-mono'],
     [qr/^lib.*-(?:java|gcj)$/         => 'java'],
@@ -109,6 +109,7 @@ my @NAME_SECTION_MAPPINGS = (
     [qr/^lib.*-(?:ocaml|camlp4)-dev$/ => 'ocaml'],
     [qr/^lib.*-dev$/                  => 'libdevel'],
     [qr/^gir\d+\.\d+-.*-\d+\.\d+$/    => 'introspection'],
+    [qr/^libjs-/                      => 'web'],
 );
 
 my %VCS_EXTRACT = (
@@ -144,12 +145,12 @@ my %VCS_CANONIFY = (
     },
     cvs      => sub {
         if (
-            $_[0] =~ s{\@(?:cvs.alioth|anonscm)\.debian\.org:/cvsroot/}
+            $_[0] =~ s{\@(?:cvs\.alioth|anonscm)\.debian\.org:/cvsroot/}
                       {\@anonscm.debian.org:/cvs/}
           ) {
             $_[1] = 'vcs-field-bitrotted';
         }
-        $_[0] =~ s{\@cvs.alioth.debian.org:/cvs/}{\@anonscm.debian.org:/cvs/};
+        $_[0]=~ s{\@\Qcvs.alioth.debian.org:/cvs/}{\@anonscm.debian.org:/cvs/};
     },
     arch     => sub {
         $_[0] =~ s{https?\Q://arch.debian.org/arch/\E}
@@ -615,6 +616,12 @@ sub run {
         {
             tag 'homepage-for-cpan-package-contains-version', $orig;
         }
+        if ($homepage=~ m,/cran\.r-project\.org/web/packages/.+,){
+            tag 'homepage-for-cran-package-not-canonical', $orig;
+        }
+        if ($homepage=~ m,bioconductor\.org/packages/.*/bioc/html/.*\.html*$,){
+            tag 'homepage-for-bioconductor-package-not-canonical', $orig;
+        }
     } elsif (not $info->native) {
         if ($type eq 'source') {
             my $binary_has_homepage_field = 0;
@@ -645,7 +652,7 @@ sub run {
     # Check whether the package looks like a metapackage, used for later
     # dependency checks.  We consider a package to possibly be a metapackage if
     # it is a binary package with no files outside of /usr/share/doc and a few
-    # other directories found in metapackges.  This also catches documentation
+    # other directories found in metapackages.  This also catches documentation
     # packages, but that doesn't matter for our purposes.
     my $metapackage = 0;
     if ($type eq 'binary') {
@@ -999,7 +1006,8 @@ sub run {
                                 $prof =~ s/^!//;
                                 tag 'invalid-profile-name-in-source-relation',
                                   "$prof [$field: $part_d_orig]"
-                                  unless $KNOWN_BUILD_PROFILES->known($prof);
+                                  unless $KNOWN_BUILD_PROFILES->known($prof)
+                                  or $prof =~ /^pkg\.[a-z0-9][a-z0-9+.-]+\../;
                             }
                         }
 
