@@ -33,7 +33,7 @@ use Lintian::Check qw($known_shells_regex);
 use Lintian::Data;
 use Lintian::Relation;
 use Lintian::Tags qw(tag);
-use Lintian::Util qw(fail strip);
+use Lintian::Util qw(do_fork fail strip);
 
 # This is a map of all known interpreters.  The key is the interpreter
 # name (the binary invoked on the #! line).  The value is an anonymous
@@ -54,7 +54,7 @@ my $INTERPRETERS = Lintian::Data->new('scripts/interpreters', qr/\s*=\>\s*/o,
 # dashes, digits, and periods.
 #
 # The list contains the following values:
-#  [<path>, <dependency-relation>, <regex>, <dependency-templatel>, <version-list>]
+#  [<path>, <dependency-relation>, <regex>, <dependency-template>, <version-list>]
 #
 # Their meaning is documented in Lintian's scripts/versioned-interpreters
 # file, though they are ordered differently and there are a few differences
@@ -248,8 +248,8 @@ sub run {
     my $str_deps = $info->relation('strong');
 
     for my $filename (sort keys %{$info->scripts}) {
-        my $interpreter = $info->scripts->{$filename}->{interpreter};
-        my $calls_env = $info->scripts->{$filename}->{calls_env};
+        my $interpreter = $info->scripts->{$filename}{interpreter};
+        my $calls_env = $info->scripts->{$filename}{calls_env};
         my $path;
         $scripts{$filename} = 1;
 
@@ -371,9 +371,6 @@ sub run {
             }
         } elsif ($interpreter =~ m,/usr/local/,) {
             script_tag('interpreter-in-usr-local', $filename,"#!$interpreter");
-        } elsif ($executable{'.' . $interpreter}) {
-         # Package installs the interpreter itself, so it's probably ok.  Don't
-         # emit any tag for this.
         } elsif ($interpreter eq '/bin/env') {
             script_tag('script-uses-bin-env', $filename);
         } else {
@@ -382,8 +379,14 @@ sub run {
                 # Check if the package ships the interpreter (and it is
                 # executable).
                 my $interfile = substr $interpreter, 1;
-                my $index_info = $info->index($interfile);
-                $pinter = 1 if $index_info && ($index_info->operm & 0111);
+                $pinter = 1 if $executable{$interfile};
+            } elsif (defined $calls_env) {
+                for my $dir (qw(usr/bin bin)) {
+                    if ($executable{"$dir/$interpreter"}) {
+                        $pinter = 1;
+                        last;
+                    }
+                }
             }
             script_tag('unusual-interpreter', $filename, "#!$interpreter")
               unless $pinter;
@@ -511,8 +514,7 @@ sub run {
     # normal scripts above, because there were just enough differences to
     # make a shared function awkward.
 
-    my %added_diversions;
-    my %removed_diversions;
+    my (%added_diversions, %removed_diversions, %dh_cmd_substs);
     my $expand_diversions = 0;
     while (<$ctrl_fd>) {
         chop;
@@ -619,6 +621,11 @@ sub run {
             if (/\#DEBHELPER\#/) {
                 tag 'maintainer-script-has-unexpanded-debhelper-token', $file;
             }
+            if (/^# Automatically added by (\S+)/) {
+                my $dh_cmd = $1;
+                tag 'debhelper-autoscript-in-maintainer-scripts', $dh_cmd
+                  if not $dh_cmd_substs{$dh_cmd}++;
+            }
 
             next if m,^\s*$,;  # skip empty lines
             next if m,^\s*\#,; # skip comment lines
@@ -1205,7 +1212,7 @@ sub script_is_evil_and_wrong {
 sub check_script_syntax {
     my ($interpreter, $path) = @_;
     my $fs_path = $path->fs_path;
-    my $pid = fork();
+    my $pid = do_fork();
     if ($pid == 0) {
         open(STDOUT, '>', '/dev/null');
         open(STDERR, '>&', \*STDOUT);
