@@ -28,6 +28,7 @@ use Carp qw(croak);
 use Cwd qw(abs_path);
 use Errno qw(ENOENT);
 use Exporter qw(import);
+use POSIX qw(sigprocmask SIG_BLOCK SIG_UNBLOCK SIG_SETMASK);
 
 use constant {
     DCTRL_DEBCONF_TEMPLATE => 1,
@@ -59,10 +60,12 @@ BEGIN {
           get_deb_info
           get_dsc_info
           get_file_checksum
+          get_file_digest
           slurp_entire_file
           file_is_encoded_in_non_utf8
           is_string_utf8_encoded
           fail
+          do_fork
           strip
           lstrip
           rstrip
@@ -786,7 +789,34 @@ sub drain_pipe {
     return 1;
 }
 
-=item get_file_checksum (ALGO, FILE)
+=item get_file_digest(ALGO, FILE)
+
+Creates an ALGO digest object that is seeded with the contents of
+FILE.  If you just want the hex digest, please use
+L</get_file_checksum(ALGO, FILE)> instead.
+
+ALGO can be 'md5' or shaX, where X is any number supported by
+L<Digest::SHA> (e.g. 'sha256').
+
+This sub is a convenience wrapper around Digest::{MD5,SHA}.
+
+=cut
+
+sub get_file_digest {
+    my ($alg, $file) = @_;
+    open(my $fd, '<', $file);
+    my $digest;
+    if ($alg eq 'md5') {
+        $digest = Digest::MD5->new;
+    } elsif ($alg =~ /sha(\d+)/) {
+        $digest = Digest::SHA->new($1);
+    }
+    $digest->addfile($fd);
+    close($fd);
+    return $digest;
+}
+
+=item get_file_checksum(ALGO, FILE)
 
 Returns a hexadecimal string of the message digest checksum generated
 by the algorithm ALGO on FILE.
@@ -799,16 +829,7 @@ This sub is a convenience wrapper around Digest::{MD5,SHA}.
 =cut
 
 sub get_file_checksum {
-    my ($alg, $file) = @_;
-    open(my $fd, '<', $file);
-    my $digest;
-    if ($alg eq 'md5') {
-        $digest = Digest::MD5->new;
-    } elsif ($alg =~ /sha(\d+)/) {
-        $digest = Digest::SHA->new($1);
-    }
-    $digest->addfile($fd);
-    close($fd);
+    my $digest = get_file_digest(@_);
     return $digest->hexdigest;
 }
 
@@ -860,6 +881,37 @@ sub file_is_encoded_in_non_utf8 {
     return $line;
 }
 
+=item do_fork()
+
+Overrides fork to reset signal handlers etc. in the child.
+
+=cut
+
+sub do_fork() {
+    my ($pid, $fork_error);
+    my $orig_mask = POSIX::SigSet->new;
+    my $fork_mask = POSIX::SigSet->new;
+    $fork_mask->fillset;
+    sigprocmask(SIG_BLOCK, $fork_mask, $orig_mask)
+      or die("sigprocmask failed: $!\n");
+    $pid = CORE::fork();
+    $fork_error = $!;
+    if ($pid == 0) {
+
+        for my $sig (keys(%SIG)) {
+            if (ref($SIG{$sig}) eq 'CODE') {
+                $SIG{$sig} = 'DEFAULT';
+            }
+        }
+    }
+    sigprocmask(SIG_SETMASK, $orig_mask, undef)
+      or die("sigprocmask failed: $!\n");
+    if ($pid == -1) {
+        $! = $fork_error;
+    }
+    return $pid;
+}
+
 =item system_env (CMD)
 
 Behaves like system (CMD) except that the environment of CMD is
@@ -868,7 +920,7 @@ cleaned (as defined by L</clean_env>(1)).
 =cut
 
 sub system_env {
-    my $pid = fork;
+    my $pid = do_fork;
     if (not defined $pid) {
         return -1;
     } elsif ($pid == 0) {
